@@ -29,6 +29,9 @@ DBERROR = 'DBError'
 # 操作失败。
 FAILEDOPERATION = 'FailedOperation'
 
+# 申请资源标签的配额失败。
+FAILEDOPERATION_ALLOCATEQUOTASERROR = 'FailedOperation.AllocateQuotasError'
+
 # 访问基础网络服务失败，请稍后重试。如果持续不成功，请联系客服进行处理。
 FAILEDOPERATION_BASENETWORKACCESSERROR = 'FailedOperation.BaseNetworkAccessError'
 
@@ -113,9 +116,12 @@ FAILEDOPERATION_MASTERINSTANCEQUERYERROR = 'FailedOperation.MasterInstanceQueryE
 # 修改只读组配置失败。
 FAILEDOPERATION_MODIFYROGROUPERROR = 'FailedOperation.ModifyROGroupError'
 
-# 不符合资源所拥有的的网络数量要求。
+# 不符合资源所拥有的网络数量要求。
 FAILEDOPERATION_NETWORKNUMLIMITERROR = 'FailedOperation.NetworkNumLimitError'
 
+# 操作超过频率限制，请稍后重试。如果持续不成功，请联系客服进行处理。
+FAILEDOPERATION_OPERATEFREQUENCYLIMITEDERROR = 'FailedOperation.OperateFrequencyLimitedError'
+
 # 访问管控服务失败，请稍后重试。如果持续不成功，请联系客服进行处理。
 FAILEDOPERATION_OSSACCESSERROR = 'FailedOperation.OssAccessError'
 
@@ -239,6 +245,9 @@ INTERNALERROR_FLOWERROR = 'InternalError.FlowError'
 # 管控系统元数据访问异常，请联系客服处理。
 INTERNALERROR_INSTANCEDATAERROR = 'InternalError.InstanceDataError'
 
+# 请求执行异常。
+INTERNALERROR_INTERNALHTTPSERVERERROR = 'InternalError.InternalHttpServerError'
+
 # 后台数据解析失败，请联系客服进行处理。
 INTERNALERROR_MARSHALERROR = 'InternalError.MarshalError'
 
@@ -260,9 +269,6 @@ INVALIDACCOUNTSTATUS = 'InvalidAccountStatus'
 # 实例状态错误。
 INVALIDINSTANCESTATUS = 'InvalidInstanceStatus'
 
-# 计费相关错误，订单类型ID无效。
-INVALIDORDERNUM = 'InvalidOrderNum'
-
 # 参数错误。
 INVALIDPARAMETER = 'InvalidParameter'
 
@@ -404,12 +410,6 @@ INVALIDPARAMETERVALUE_STRUCTPARSEFAILED = 'InvalidParameterValue.StructParseFail
 # PID参数输入错误。
 INVALIDPID = 'InvalidPid'
 
-# 计费相关错误，不允许对当前实例进行对应的新购/续费/配置变更操作。
-INVALIDTRADEOPERATE = 'InvalidTradeOperate'
-
-# 计费相关错误，输入的代金券无效。
-INVALIDVOUCHERID = 'InvalidVoucherId'
-
 # 超过配额限制。
 LIMITEXCEEDED = 'LimitExceeded'
 
@@ -455,6 +455,9 @@ OPERATIONDENIED_ROGROUPSTATUSERROR = 'OperationDenied.ROGroupStatusError'
 # 只读实例不支持ipv6。
 OPERATIONDENIED_ROINSTANCEIPV6NOTSUPPORTEDERROR = 'OperationDenied.ROInstanceIpv6NotSupportedError'
 
+# 只读实例状态限制当前操作。
+OPERATIONDENIED_ROINSTANCESTATUSLIMITOPERROR = 'OperationDenied.ROInstanceStatusLimitOpError'
+
 # 只读节点总数不能超过上限值。
 OPERATIONDENIED_ROINSTANCECOUNTEXEEDERROR = 'OperationDenied.RoInstanceCountExeedError'
 
@@ -476,9 +479,6 @@ REQUESTLIMITEXCEEDED = 'RequestLimitExceeded'
 # 当前地域购买此规格的实例没有足够的资源。
 RESOURCEINSUFFICIENT_RESOURCENOTENOUGH = 'ResourceInsufficient.ResourceNotEnough'
 
-# 资源不存在。
-RESOURCENOTFOUND = 'ResourceNotFound'
-
 # 实例不存在。
 RESOURCENOTFOUND_INSTANCENOTFOUNDERROR = 'ResourceNotFound.InstanceNotFoundError'
 
@@ -506,5 +506,8 @@ UNKNOWNERROR = 'UnknownError'
 # 未知参数错误。
 UNKNOWNPARAMETER = 'UnknownParameter'
 
+# 操作不支持。
+UNSUPPORTEDOPERATION = 'UnsupportedOperation'
+
 # VPC相关错误。
 VPCERROR = 'VpcError'
